package org.w3c.rdf.examples;

import org.w3c.rdf.model.*;
import org.w3c.rdf.model.impl.ModelImpl;
import org.w3c.rdf.syntax.strawman.StrawmanParser;
import org.w3c.rdf.syntax.sirpac.SiRS;
import org.w3c.rdf.util.*;

/**
 * A simple demo program that parses RDF from a given URL,
 * serializes it back into RDF/XML, and dumps the triples.
 *
 * <p>Try <code>java org.w3c.rdf.examples.StrawmanToMS10 http://www-db.stanford.edu/~melnik/rdf/examples/data.xml</code>
 */

public class StrawmanToMS10 {

  public static void main(String[] args) throws Exception {

    if(args.length == 0) {
      System.err.println("StrawmanToMS10 <fileNameOrURL>");
      System.exit(1);
    }

    String fileNameOrURL = args[0];
    Model m = new ModelImpl();
    RDFUtil.parse(fileNameOrURL, new StrawmanParser(), m);

    System.err.println("\nSERIALIZED MODEL:\n");
    RDFUtil.dumpModel(m, System.out, new SiRS());

    System.err.println("\nTRIPLES:\n");
    RDFUtil.printStatements(m, System.out);

    System.err.println("\nModel " + m.getURI() + " of size " + m.size() + "\n");

  }
}
